@@ -76,16 +76,14 @@ class SnapshotSearchAPIV2Request:
             header["User-Agent"] += " " + self._user_agent[2]
 
         for r in range(DEFAULT_RETRY):
-            response = requests.get(
-                url, timeout=(timeout / 4, timeout * 3 / 4), headers=header
-            )
+            response = requests.get(url, timeout=(timeout / 4, timeout * 3 / 4), headers=header)
             response_time = response.elapsed.total_seconds()
             response_obj = SnapshotSearchAPIV2Result(self._query, response)
             total_time += response_time
 
             if total_time > timeout:
                 raise TimeoutError("通信がタイムアウトしました")
-            elif "meta" in response_obj.json() and response_obj.status() == 200:
+            elif "meta" in response_obj.json() and response_obj.status()[0] == 200:
                 break
             time.sleep(response_time)
         else:
